@@ -40,7 +40,7 @@ impl<'a> Subtable12<'a> {
         s.skip::<u16>(); // reserved
         s.skip::<u32>(); // length
         s.skip::<u32>(); // language
-        let count: u32 = s.read()?;
+        let count = s.read::<u32>()?;
         let groups = s.read_array32::<SequentialMapGroup>(count)?;
         Some(Self { groups })
     }
