@@ -29,18 +29,6 @@ pub use format12::Subtable12;
 pub use format13::Subtable13;
 pub use format14::{Subtable14, GlyphVariationResult};
 
-
-/// A character encoding subtable.
-#[derive(Clone, Copy, Debug)]
-pub struct Subtable<'a> {
-    /// Subtable platform.
-    pub platform_id: PlatformId,
-    /// Subtable encoding.
-    pub encoding_id: u16,
-    /// A subtable format.
-    pub format: Format<'a>,
-}
-
 /// A character encoding subtable variant.
 #[allow(missing_docs)]
 #[derive(Clone, Copy, Debug)]
@@ -56,6 +44,18 @@ pub enum Format<'a> {
     UnicodeVariationSequences(Subtable14<'a>),
 }
 
+
+/// A character encoding subtable.
+#[derive(Clone, Copy, Debug)]
+pub struct Subtable<'a> {
+    /// Subtable platform.
+    pub platform_id: PlatformId,
+    /// Subtable encoding.
+    pub encoding_id: u16,
+    /// A subtable format.
+    pub format: Format<'a>,
+}
+
 impl<'a> Subtable<'a> {
     /// Checks that the current encoding is Unicode compatible.
     #[inline]
@@ -214,6 +214,7 @@ impl<'a> Subtables<'a> {
     }
 
     /// Returns the number
+    #[inline]
     pub fn len(&self) -> u16 {
         self.records.len()
     }
@@ -242,6 +243,7 @@ pub struct SubtablesIter<'a> {
 impl<'a> Iterator for SubtablesIter<'a> {
     type Item = Subtable<'a>;
 
+    #[inline]
     fn next(&mut self) -> Option<Self::Item> {
         if self.index < self.subtables.len() {
             self.index += 1;
@@ -266,7 +268,7 @@ impl<'a> Table<'a> {
     pub fn parse(data: &'a [u8]) -> Option<Self> {
         let mut s = Stream::new(data);
         s.skip::<u16>(); // version
-        let count: u16 = s.read()?;
+        let count = s.read::<u16>()?;
         let records = s.read_array16::<EncodingRecord>(count)?;
         Some(Table { subtables: Subtables { data, records }})
     }
