@@ -6,47 +6,6 @@ use core::num::NonZeroU16;
 use crate::parser::{Stream, F2DOT14, LazyArray16, NumFrom};
 use crate::{loca, GlyphId, OutlineBuilder, Rect, BBox};
 
-/// A [Glyph Data Table](
-/// https://docs.microsoft.com/en-us/typography/opentype/spec/glyf).
-#[derive(Clone, Copy)]
-pub struct Table<'a> {
-    pub(crate) data: &'a [u8],
-    loca_table: loca::Table<'a>,
-}
-
-impl core::fmt::Debug for Table<'_> {
-    fn fmt(&self, f: &mut core::fmt::Formatter) -> core::fmt::Result {
-        write!(f, "Table {{ ... }}")
-    }
-}
-
-impl<'a> Table<'a> {
-    /// Parses a table from raw data.
-    #[inline]
-    pub fn parse(loca_table: loca::Table<'a>, data: &'a [u8]) -> Option<Self> {
-        Some(Table { loca_table, data })
-    }
-
-    /// Outlines a glyph.
-    #[inline]
-    pub fn outline(
-        &self,
-        glyph_id: GlyphId,
-        builder: &mut dyn OutlineBuilder,
-    ) -> Option<Rect> {
-        let mut b = Builder::new(Transform::default(), BBox::new(), builder);
-        let glyph_data = self.get(glyph_id)?;
-        outline_impl(self.loca_table, self.data, glyph_data, 0, &mut b)
-    }
-
-    #[inline]
-    pub(crate) fn get(&self, glyph_id: GlyphId) -> Option<&'a [u8]> {
-        let range = self.loca_table.glyph_range(glyph_id)?;
-        self.data.get(range)
-    }
-}
-
-
 pub(crate) struct Builder<'a> {
     pub builder: &'a mut dyn OutlineBuilder,
     pub transform: Transform,
@@ -269,7 +228,7 @@ impl<'a> Iterator for CompositeGlyphIter<'a> {
     #[inline]
     fn next(&mut self) -> Option<Self::Item> {
         let flags = CompositeGlyphFlags(self.stream.read::<u16>()?);
-        let glyph_id: GlyphId = self.stream.read()?;
+        let glyph_id = self.stream.read::<GlyphId>()?;
 
         let mut ts = Transform::default();
 
@@ -541,13 +500,13 @@ fn outline_impl(
     data: &[u8],
     depth: u8,
     builder: &mut Builder,
-) -> Option<Rect> {
+) -> Option<Option<Rect>> {
     if depth >= MAX_COMPONENTS {
         return None;
     }
 
     let mut s = Stream::new(data);
-    let number_of_contours: i16 = s.read()?;
+    let number_of_contours = s.read::<i16>()?;
     s.advance(8); // Skip bbox. We use calculated one.
 
     if number_of_contours > 0 {
@@ -566,8 +525,7 @@ fn outline_impl(
                 if let Some(glyph_data) = glyf_table.get(range) {
                     let transform = Transform::combine(builder.transform, comp.transform);
                     let mut b = Builder::new(transform, builder.bbox, builder.builder);
-                    // We don't care about errors here.
-                    let _ = outline_impl(loca_table, glyf_table, glyph_data, depth + 1, &mut b);
+                    outline_impl(loca_table, glyf_table, glyph_data, depth + 1, &mut b)?;
 
                     // Take updated bbox.
                     builder.bbox = b.bbox;
@@ -577,10 +535,10 @@ fn outline_impl(
     }
 
     if builder.bbox.is_default() {
-        return None;
+        return Some(None);
     }
 
-    builder.bbox.to_rect()
+    Some(builder.bbox.to_rect())
 }
 
 #[inline]
@@ -600,7 +558,7 @@ pub(crate) fn parse_simple_outline(
     }
 
     // Skip instructions byte code.
-    let instructions_len: u16 = s.read()?;
+    let instructions_len = s.read::<u16>()?;
     s.advance(usize::from(instructions_len));
 
     let flags_offset = s.offset();
@@ -634,7 +592,7 @@ fn resolve_coords_len(
 
         // The number of times a glyph point repeats.
         repeats = if flags.repeat_flag() {
-            let repeats: u8 = s.read()?;
+            let repeats = s.read::<u8>()?;
             u32::from(repeats) + 1
         } else {
             1
@@ -667,3 +625,44 @@ fn resolve_coords_len(
 
     Some((x_coords_len, y_coords_len))
 }
+
+
+/// A [Glyph Data Table](
+/// https://docs.microsoft.com/en-us/typography/opentype/spec/glyf).
+#[derive(Clone, Copy)]
+pub struct Table<'a> {
+    pub(crate) data: &'a [u8],
+    loca_table: loca::Table<'a>,
+}
+
+impl core::fmt::Debug for Table<'_> {
+    fn fmt(&self, f: &mut core::fmt::Formatter) -> core::fmt::Result {
+        write!(f, "Table {{ ... }}")
+    }
+}
+
+impl<'a> Table<'a> {
+    /// Parses a table from raw data.
+    #[inline]
+    pub fn parse(loca_table: loca::Table<'a>, data: &'a [u8]) -> Option<Self> {
+        Some(Table { loca_table, data })
+    }
+
+    /// Outlines a glyph.
+    #[inline]
+    pub fn outline(
+        &self,
+        glyph_id: GlyphId,
+        builder: &mut dyn OutlineBuilder,
+    ) -> Option<Rect> {
+        let mut b = Builder::new(Transform::default(), BBox::new(), builder);
+        let glyph_data = self.get(glyph_id)?;
+        outline_impl(self.loca_table, self.data, glyph_data, 0, &mut b)?
+    }
+
+    #[inline]
+    pub(crate) fn get(&self, glyph_id: GlyphId) -> Option<&'a [u8]> {
+        let range = self.loca_table.glyph_range(glyph_id)?;
+        self.data.get(range)
+    }
+}
