@@ -2,7 +2,6 @@ pub mod cbdt;
 pub mod cblc;
 mod cff;
 pub mod cmap;
-pub mod gdef;
 pub mod glyf;
 pub mod head;
 pub mod hhea;
@@ -18,6 +17,10 @@ pub mod svg;
 pub mod vhea;
 pub mod vorg;
 
+#[cfg(feature = "opentype-layout")] pub mod gdef;
+#[cfg(feature = "opentype-layout")] pub mod gsub;
+#[cfg(feature = "opentype-layout")] pub mod gpos;
+
 #[cfg(feature = "variable-fonts")] pub mod avar;
 #[cfg(feature = "variable-fonts")] pub mod fvar;
 #[cfg(feature = "variable-fonts")] pub mod gvar;
@@ -25,4 +28,5 @@ pub mod vorg;
 #[cfg(feature = "variable-fonts")] pub mod mvar;
 
 pub use cff::cff1;
+pub use cff::CFFError;
 #[cfg(feature = "variable-fonts")] pub use cff::cff2;
